@@ -1,8 +1,5 @@
-import json
 from pathlib import Path
 
-from patent_client.util.test import compare_dicts
-
 from .api import FamilyApi
 
 test_dir = Path(__file__).parent / "fixtures" / "examples"
@@ -11,5 +8,7 @@ expected_dir = Path(__file__).parent / "fixtures" / "expected"
 
 def test_example():
     result = FamilyApi.get_family("EP1000000A1")
-    expected = json.loads((expected_dir / "example.json").read_text())
-    compare_dicts(json.loads(result.to_json()), expected)
+    expected_file = expected_dir / "example.xml"
+    # expected_file.write_text(result)
+    expected = expected_file.read_text()
+    assert expected == result
