@@ -1,3 +1,4 @@
+import datetime
 from pathlib import Path
 
 import requests_cache
@@ -6,12 +7,17 @@ from patent_client.version import __version__
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 
+max_age = SETTINGS.CACHE.MAX_AGE
+
+if isinstance(max_age, str) and "day" in max_age.lower():
+    max_age = int(max_age.split()[0])
+
 
 class PatentClientSession(requests_cache.CachedSession):
     def __init__(self):
         super().__init__(
             Path(SETTINGS.DEFAULT.BASE_DIR).expanduser() / SETTINGS.CACHE.PATH,
-            expire_after=SETTINGS.CACHE.MAX_AGE,
+            expire_after=datetime.timedelta(days=max_age),
             backend="sqlite",
             allowable_methods=("GET", "POST"),
             ignored_parameters=[
