@@ -1,9 +1,10 @@
-import json
+from collections import defaultdict
 from typing import *
 
-from yankee.util import clean_whitespace
-from yankee.json.schema import Schema, fields as f
-from collections import defaultdict
+from patent_client.util.format import clean_whitespace
+from yankee.json.schema import fields as f
+from yankee.json.schema import Schema
+
 
 class InventorNameField(f.Combine):
     name_line_one = f.Str()
@@ -25,9 +26,8 @@ class InventorAddressField(f.Combine):
     country = f.Str()
 
     def combine_func(self, obj):
-        obj = defaultdict(lambda: "", obj.to_dict())
         return clean_whitespace(
-            "{street_one}\n{street_two}\n{city}, {geo_code} {postal_code} {country}".format_map(obj),
+            f'{obj.street_one or ""}\n{obj.street_two or ""}\n{obj.city or ""}, {obj.geo_code or ""} {obj.postal_code or ""} {obj.country or ""}',
             preserve_newlines=True,
         )
 
@@ -150,6 +150,9 @@ class ForeignPrioritySchema(Schema):
 
 
 class DocumentSchema(Schema):
+    class Meta:
+        use_model = True
+
     access_level_category = f.Str()
     appl_id = f.Str("applicationNumberText")
     category = f.Str("documentCategory")
@@ -224,6 +227,9 @@ class AssignmentSchema(Schema):
 
 
 class USApplicationSchema(Schema):
+    class Meta:
+        use_model = True
+
     # Basic Bibliographic Data
     appl_id = f.Str()
     app_confr_number = f.Str()
@@ -268,6 +274,9 @@ class USApplicationSchema(Schema):
 
 
 class PedsPageSchema(Schema):
+    class Meta:
+        use_model = True
+
     index_last_updated = f.Date("queryResults.indexLastUpdatedDate")
     num_found = f.Int("queryResults.searchResponse.response.numFound")
     applications = f.List(USApplicationSchema, "queryResults.searchResponse.response.docs")
