@@ -1,16 +1,17 @@
 import datetime
+import re
 from dataclasses import dataclass
 from dataclasses import field
 from fileinput import filename
+from pathlib import Path
 from typing import *
 
+from patent_client import session
 from patent_client.util import Model
 from yankee.data import ListCollection
 
 from ...util.base.related import get_model
-from patent_client import session
-from pathlib import Path
-import re
+
 
 @dataclass
 class AdditionalRespondent(Model):
@@ -123,8 +124,10 @@ class PtabProceeding(Model):
             patent_number=self.respondent_patent_number
         )
 
+
 fname_re = re.compile(r"[<>:\"/\|?*]")
 
+
 @dataclass
 class PtabDocument(Model):
     __manager__ = "patent_client.uspto.ptab.manager.PtabDocumentManager"
@@ -152,12 +155,13 @@ class PtabDocument(Model):
         filename = filename.encode(encoding="ascii", errors="ignore").decode("ascii")
         filename = fname_re.sub("", filename)
         out_path = Path(path) / filename
-        with session.get(f"https://developer.uspto.gov/ptab-api/documents/{self.document_identifier}/download", verify=False) as r:
+        with session.get(
+            f"https://developer.uspto.gov/ptab-api/documents/{self.document_identifier}/download", verify=False
+        ) as r:
             r.raise_for_status()
             with out_path.open("wb") as f:
                 for chunk in r.iter_content(chunk_size=8192):
                     f.write(chunk)
-    
 
 
 @dataclass
