@@ -1,5 +1,5 @@
-from patent_client.util.json import Schema
 from yankee.json import fields as f
+from yankee.json import Schema
 
 
 class AdditionalRespondentSchema(Schema):
